@@ -81,7 +81,8 @@ from web3.datastructures import (
 )
 from web3.exceptions import (
     BlockNotFound,
-    SolidityError,
+    ContractLogicError,
+    InvalidParityMode,
     TransactionNotFound,
 )
 from web3.types import (
@@ -503,29 +504,40 @@ def raise_solidity_error_on_revert(response: RPCResponse) -> RPCResponse:
 
     # Ganache case:
     if isinstance(data, dict) and response['error'].get('message'):
-        raise SolidityError(f'execution reverted: {response["error"]["message"]}')
+        raise ContractLogicError(f'execution reverted: {response["error"]["message"]}')
 
     # Parity/OpenEthereum case:
     if data.startswith('Reverted '):
         # "Reverted", function selector and offset are always the same for revert errors
         prefix = 'Reverted 0x08c379a00000000000000000000000000000000000000000000000000000000000000020'  # noqa: 501
         if not data.startswith(prefix):
-            raise SolidityError('execution reverted')
+            raise ContractLogicError('execution reverted')
 
         reason_length = int(data[len(prefix):len(prefix) + 64], 16)
         reason = data[len(prefix) + 64:len(prefix) + 64 + reason_length * 2]
-        raise SolidityError(f'execution reverted: {bytes.fromhex(reason).decode("utf8")}')
+        raise ContractLogicError(f'execution reverted: {bytes.fromhex(reason).decode("utf8")}')
 
     # Geth case:
     if 'message' in response['error'] and response['error'].get('code', '') == 3:
-        raise SolidityError(response['error']['message'])
+        raise ContractLogicError(response['error']['message'])
+
+    # Geth Revert without error message case:
+    if 'execution reverted' in response['error'].get('message'):
+        raise ContractLogicError('execution reverted')
 
     return response
 
 
+def raise_invalid_parity_mode(response: RPCResponse) -> NoReturn:
+    # eth-tester sends back an invalid RPCError, which makes mypy complain
+    error_message = response['error'].get('message')  # type: ignore
+    raise InvalidParityMode(error_message)
+
+
 ERROR_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_estimateGas: raise_solidity_error_on_revert,
     RPC.eth_call: raise_solidity_error_on_revert,
+    RPC.parity_setMode: raise_invalid_parity_mode,
 }
 
 
